#package require ooxml
source ../ooxml.tcl

array set workbook [ooxml::xl_read printArea.xlsx]

#parray workbook

set spreadsheet [::ooxml::xl_write new]
$spreadsheet presetstyles workbook
$spreadsheet presetsheets workbook
#$spreadsheet write new.xlsx
#$spreadsheet destroy